Struct EthereumReceipt
pub struct EthereumReceipt<T = TxType, L = Log> {
pub tx_type: T,
pub success: bool,
pub cumulative_gas_used: u64,
pub logs: Vec<L>,
}Expand description
Typed ethereum transaction receipt. Receipt containing result of transaction execution.
Fields
tx_type: TReceipt type.
success: boolIf transaction is executed successfully.
This is the statusCode
cumulative_gas_used: u64Gas used
logs: Vec<L>Log send from contracts.
Implementations
impl<T, L> EthereumReceipt<T, L>
impl<T, L> EthereumReceipt<T, L>
pub fn map_logs<U>(self, f: impl FnMut(L) -> U) -> EthereumReceipt<T, U>
pub fn map_logs<U>(self, f: impl FnMut(L) -> U) -> EthereumReceipt<T, U>
Converts the receipt’s log type by applying a function to each log.
Returns the receipt with the new log type.
impl<T> EthereumReceipt<T>where
T: TxTy,
impl<T> EthereumReceipt<T>where
T: TxTy,
pub fn rlp_encoded_fields_length(&self, bloom: &Bloom) -> usize
pub fn rlp_encoded_fields_length(&self, bloom: &Bloom) -> usize
Returns length of RLP-encoded receipt fields with the given [Bloom] without an RLP header.
pub fn rlp_encode_fields(&self, bloom: &Bloom, out: &mut dyn BufMut)
pub fn rlp_encode_fields(&self, bloom: &Bloom, out: &mut dyn BufMut)
RLP-encodes receipt fields with the given [Bloom] without an RLP header.
pub fn rlp_header_inner(&self, bloom: &Bloom) -> Header
pub fn rlp_header_inner(&self, bloom: &Bloom) -> Header
Returns RLP header for this receipt encoding with the given [Bloom].
pub fn rlp_decode_inner(
buf: &mut &[u8],
tx_type: T,
) -> Result<ReceiptWithBloom<EthereumReceipt<T>>, Error>
pub fn rlp_decode_inner( buf: &mut &[u8], tx_type: T, ) -> Result<ReceiptWithBloom<EthereumReceipt<T>>, Error>
RLP-decodes receipt and [Bloom] into [ReceiptWithBloom] instance.
pub fn calculate_receipt_root_no_memo(
receipts: &[EthereumReceipt<T>],
) -> FixedBytes<32>
pub fn calculate_receipt_root_no_memo( receipts: &[EthereumReceipt<T>], ) -> FixedBytes<32>
Calculates the receipt root for a list of receipts.
NOTE: Prefer [crate::proofs::calculate_receipt_root] if you have log blooms memoized.